package currentweek.android.uoc.edu.aliapp;

import android.content.Context;
import android.content.Intent;
import android.support.annotation.NonNull;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.support.v7.view.menu.MenuView;
import android.support.v7.widget.DefaultItemAnimator;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.support.v7.widget.StaggeredGridLayoutManager;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.TextView;
import android.widget.Toast;

import java.util.Arrays;
import java.util.List;

import model.AppConfig;

import static currentweek.android.uoc.edu.aliapp.MainActivity.session;
import static model.AppConfig.C_NOVIOS;
import static model.AppConfig.C_PADRINOS;
import static model.AppConfig.C_RELOJES;



/*
* Esta clase se encarga del funcionamiento de los catálogos de la aplicación.
* Los catálogos tienen una clasificación inicial por tipos o marcas.
* En esta clase desarrollamos un RecyclerView para crear una lista
* con el título de la clasificación. Si pulsamos en un elemento de
* estas listas, lanzaremos la activity que se encarga de listar los
* productos (ArticuloActivity). Para ello, le pasamos el tipo de
* elemento que tiene que mostar mediante una cadena de caracteres.
* */
public class CatalogoActivity extends AppCompatActivity {

    private final String TIPO_CATALOGO = "TIPO_CATALOGO";

    // Tipos de catálogos
    private final String PAD = "PADRINOS";
    private final String NVS = "NOVIOS";
    private final String REL = "RELOJES";

    private String tipoCatalogo;

    private List<String> listaOpcionesCatalogo;
    private RecyclerView recyclerView;
    private Context context;
    private SimpleItemRecyclerViewAdapterCatalogo adapter = null;



    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_catalogo);

        // Permitir botón atrás
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);


        // Obtener el catálogo que hay que listar
        Intent intent = getIntent();
        Bundle bundle = intent.getExtras();

        // Default catalogo
        listaOpcionesCatalogo = C_PADRINOS;

        recyclerView = findViewById(R.id.listaCatalogo);
        context = this.getApplicationContext();
        recyclerView.setLayoutManager(new StaggeredGridLayoutManager(2, LinearLayoutManager.VERTICAL));

        // En funcion del tipo de catálogo que hay que listar obtendremos unas categorias u otras
        if(bundle!=null) {
            tipoCatalogo = (String) bundle.get(TIPO_CATALOGO);

            switch (tipoCatalogo){
                case PAD:
                    listaOpcionesCatalogo = C_PADRINOS;
                    inicializarLista();
                    break;

                case NVS:
                    listaOpcionesCatalogo = C_NOVIOS;
                    inicializarLista();
                    break;

                case REL:
                    listaOpcionesCatalogo = C_RELOJES;
                    inicializarLista();
                    break;
            }
        }





    }


    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_superior, menu);

        return true;
    }


    @Override
    public boolean onPrepareOptionsMenu(Menu menu) {

        // Deshabilitar cerrar sesión porque no es necesario estar logueado para esta opción
        MenuItem btnSesion = menu.findItem(R.id.action_settings);
        btnSesion.setVisible(false);

        return true;
    }


    @Override
    public boolean onOptionsItemSelected(MenuItem item) {

        switch (item.getItemId()) {
            case android.R.id.home: //hago un case por si en un futuro agrego mas opciones
                Log.i("ActionBar", "Atrás!");
                finish();
                return true;

            case R.id.action_settings_favoritos:
                Log.d("favoritos", "Ver favoritos");

                Intent i = FavoritosActivity.makeIntent(this);
                startActivity(i);
                return true;

            case R.id.action_settings_home:
                Intent goHome = MainActivity.makeIntent(this);
                startActivity(goHome);
                return true;

            default:
                return super.onOptionsItemSelected(item);
        }

    }



    private  void inicializarLista() {
        adapter = new SimpleItemRecyclerViewAdapterCatalogo(listaOpcionesCatalogo);
        recyclerView.setItemAnimator(new DefaultItemAnimator());
        recyclerView.setAdapter(adapter);
    }


    public static Intent makeIntent(Context context) {
        return new Intent(context, CatalogoActivity.class);
    }







    // Diseño de la lista de CATALOGOS
    public class SimpleItemRecyclerViewAdapterCatalogo extends RecyclerView.Adapter<SimpleItemRecyclerViewAdapterCatalogo.ViewHolder> {

        private List<String> mValues;


        public class ViewHolder extends RecyclerView.ViewHolder {
            // Views of each item of the list
            public View mView;
            public TextView mTitulo;


            /*
             * Constructor that defines the views
             * */
            public ViewHolder(View view) {
                super(view);

                mView = view;
                mTitulo = view.findViewById(R.id.lblTituloCatalogo);

            }

        }


        /*
         * Constructor that loads the list content
         * */
        public SimpleItemRecyclerViewAdapterCatalogo(List<String> myDataset) {
            mValues = myDataset;
        }

        /*
         * We establish the model of each item of the list
         * */
        @NonNull
        @Override
        public SimpleItemRecyclerViewAdapterCatalogo.ViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {

            View v = LayoutInflater.from(parent.getContext()).inflate(R.layout.item_catalogo, parent, false);
            SimpleItemRecyclerViewAdapterCatalogo.ViewHolder vh = new SimpleItemRecyclerViewAdapterCatalogo.ViewHolder(v);

            return vh;

        }


        /*
         * In each item of the list, we upload the information of a follower
         * */
        @Override
        public void onBindViewHolder(@NonNull SimpleItemRecyclerViewAdapterCatalogo.ViewHolder holder, final int position) {

            // Set follower info
            String item = mValues.get(position);

            holder.mTitulo.setText(item);

            holder.mView.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {

                    Log.d("tipo producto", mValues.get(position));
                    Intent intent = ArticuloActivity.makeIntent(context);
                    intent.putExtra("TIPO_LISTA", mValues.get(position));
                    startActivity(intent);

                }
            });



        }

        @Override
        public int getItemCount() {
            return mValues.size();
        }

    }
}
