package currentweek.android.uoc.edu.aliapp;

import android.app.ProgressDialog;
import android.content.Context;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.graphics.*;
import android.graphics.drawable.Drawable;
import android.net.Uri;
import android.os.Build;
import android.provider.MediaStore;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.webkit.WebView;
import android.webkit.WebViewClient;
import android.widget.ImageButton;
import android.widget.ImageView;
import android.widget.TextView;
import android.widget.Toast;

import com.android.volley.Request;
import com.android.volley.Response;
import com.android.volley.VolleyError;
import com.android.volley.toolbox.StringRequest;
import com.squareup.picasso.Picasso;
import com.squareup.picasso.Target;

import org.json.JSONException;
import org.json.JSONObject;

import java.io.ByteArrayOutputStream;
import java.util.HashMap;
import java.util.Map;

import model.AppConfig;
import model.AppController;
import model.Producto;
import model.SQLiteHandler;

import static currentweek.android.uoc.edu.aliapp.MainActivity.session;
import static model.AppConfig.DEFAULT_URL;
import static model.AppConfig.LOGO_JOYERIA;

public class DetalleProductoActivity extends AppCompatActivity {

    private String TEXT_TO_SHARE = "Joyerías Adeley";

    private static final int PERMISO_REQUEST_WRITE_EXTERNAL_STORAGE = 101;
    private static final String TAG = "Detalle Producto";
    public static final String CURRENT_POSITION = "CURRENT_POSITION";
    public static final String CURRENT_ID = "SEARCH_BY_ID";

    private boolean permisos = false;
    private Context context;

    private String nombre;
    private String descripcion;
    private String urlCompra;

    private  String urlFoto;

    private int position;
    private String id;

    private TextView lblNombre;
    private TextView lblDescripcion;
    private ImageView imagenDetalle;
    private ImageView btnCompartir;
    private ImageButton btnfavoritos;



    private WebView tienda;

    private Producto mItem;
    private SQLiteHandler db;




    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_detalle_producto);

        // habilitar botón atrás en la app
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);

        context = this.getApplicationContext();
        db = new SQLiteHandler(getApplicationContext());

        lblNombre = findViewById(R.id.tituloDetalle);
        lblDescripcion = findViewById(R.id.descripcionDetalle);
        imagenDetalle = findViewById(R.id.imagenDetalle);
        tienda = findViewById(R.id.tiendaWeb);

        btnCompartir = findViewById(R.id.btnCompartirDetalle);
        btnCompartir.setOnClickListener(new View.OnClickListener() {

            public void onClick(View view) {
                if(permisos)
                    compartirOtrasApps();
                else
                    preguntarPermisos();
            }
        });

        // Obtener información del intent
        Intent intent = getIntent();
        Bundle bundle = intent.getExtras();


        if (bundle != null) {
            position = bundle.getInt(CURRENT_POSITION);
            if(position != 0) {
                mItem = ArticuloActivity.getListaProductos().get(position - 1);

                nombre = mItem.getNombre();
                descripcion = mItem.getRef() + "\n\n" + mItem.getDescripcion() + "\n\n" + mItem.getPrecio() + "€";
                urlFoto = mItem.getFoto();

                urlCompra = mItem.getUrl();
                cargarVistas();
            }
            else {
                id = bundle.getString(CURRENT_ID);
                buscarProductoById();
            }

        }

        // btn favoritos
        btnfavoritos = findViewById(R.id.btnFavorito);
        if(db.existProduct(mItem.getId())) {
            btnfavoritos.setImageResource(android.R.drawable.star_big_on);
        }
    }


    public static Intent makeIntent(Context context) {
        return new Intent(context, ArticuloActivity.class);
    }



    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_superior, menu);
        return true;
    }


    @Override
    public boolean onOptionsItemSelected(MenuItem item) {

        switch (item.getItemId()) {
            case android.R.id.home: //hago un case por si en un futuro agrego mas opciones
                Log.i("ActionBar", "Atrás!");
                finish();
                return true;

            case R.id.action_settings:
                session.setLogin(false);
                Toast.makeText(this, R.string.cerrar_sesion, Toast.LENGTH_SHORT).show();
                Log.d("sesion", "Cerrando sesión...");

                Intent intent = MainActivity.makeIntent(this);
                startActivity(intent);
                finish();
                return true;

            case R.id.action_settings_favoritos:
                Log.d("favoritos", "Ver favoritos");

                Intent i = FavoritosActivity.makeIntent(this);
                startActivity(i);
                return true;

            case R.id.action_settings_home:
                Intent goHome = MainActivity.makeIntent(this);
                startActivity(goHome);
                return true;

            default:
                return super.onOptionsItemSelected(item);
        }

    }



    private void cargarVistas() {
        lblNombre.setText(nombre);
        lblDescripcion.setText(descripcion);

        if (urlFoto != null && urlFoto != "")
            Picasso.with(this).load(urlFoto).into(imagenDetalle);
        else
            Picasso.with(this).load(LOGO_JOYERIA).into(imagenDetalle);

    }


    public void adquirirEnTienda(View view) {
        Intent intent = TiendasActivity.makeIntent(this);
        startActivity(intent);
    }


    public void comprar(View view) {

        // Hacemos la vista web visible
        tienda.setVisibility(View.VISIBLE);

        final ProgressDialog progressDialog = new ProgressDialog(this);
        progressDialog.setIcon(R.mipmap.ic_launcher);
        progressDialog.setMessage("Cargando...");
        progressDialog.show();

        //Carga página.
        tienda.loadUrl(urlCompra);
        //Define WebViewClient() para poder leer eventos que ocurren durante el cargado de contenido en el WebView.
        tienda.setWebViewClient(new WebViewClient(){
            @Override
            public void onPageFinished(WebView view, String url) {
                super.onPageFinished(view, url);
                //elimina ProgressBar.
                progressDialog.dismiss();
            }
        });
    }


    public void insertarAFavoritos(View view){

        // Si el producto no existe lo insertamos
        if(!db.existProduct(mItem.getId())) {
            db.insertarProducto(mItem.getNombre(), mItem.getDescripcion(), Integer.parseInt(mItem.getId()), mItem.getCategoria(), urlFoto, mItem.getPrecio());
            Toast.makeText(this, "Insertado a favoritos", Toast.LENGTH_SHORT).show();
        }
        else {
            Toast.makeText(this, "El producto ya se encontraba en favoritos", Toast.LENGTH_SHORT).show();
        }

    }



    public void mostrarWebView() {
        //lblDescripcion.setText();
        // Hacemos el formulario vilible
        tienda.setVisibility(View.VISIBLE);

        // Instanciamos el cliente webView de la clase CodePunkerWebView que hemos generado
        WebViewClient client = new WebViewClient() {

            @Override
            public void onPageStarted(WebView codePunkerWebView, String url, Bitmap favicon) {
                super.onPageStarted(codePunkerWebView, url, favicon);
            }

            @Override
            public void onPageFinished(WebView codePunkerWebView, String url) {
                super.onPageFinished(codePunkerWebView, url);
            }
        };

        // Asignamos el cliente al WebView
        tienda.setWebViewClient(client);

        // Cargamos el contenido con loadUrl
        tienda.loadUrl(urlCompra);

    }


    private void preguntarPermisos() {
        // Versiones superiores de android con solicitud de permisos en tiempo de ejecución
        if (Build.VERSION.SDK_INT >= 23) {
            // Comprobar el estado del permiso que necesitamos
            int permisoEscritura = checkSelfPermission(android.Manifest.permission.WRITE_EXTERNAL_STORAGE);

            // Si no se tiene el permiso, según la acción se solicitará el permiso que neceistamos
            if (permisoEscritura != PackageManager.PERMISSION_GRANTED) {
                requestPermissions(new String[]{android.Manifest.permission.WRITE_EXTERNAL_STORAGE},
                        PERMISO_REQUEST_WRITE_EXTERNAL_STORAGE);
                // Si se tiene el permiso
            } else if (permisoEscritura == PackageManager.PERMISSION_GRANTED){
                compartirOtrasApps();
            }
            permisos = true;
        }
        else {
            permisos = true;
            compartirOtrasApps();
        }
    }



    private void adjuntarImagen(Uri img) {
        Intent intent = new Intent();
        intent.setAction(Intent.ACTION_SEND);
        intent.putExtra(Intent.EXTRA_STREAM, img);

        String textoCompartir = getString(R.string.texto_compartir) + mItem.getDescripcion() + " (" + mItem.getPrecio() + "€).";
        intent.putExtra(Intent.EXTRA_TEXT, textoCompartir);

        intent.setType("image/*");

        // Generamos un selector con las aplicaciones disponibles para hacer el envío de información
        Intent chooser = Intent.createChooser(intent, "Compartir otras aplicaciones");
        if (intent.resolveActivity(getPackageManager()) != null) {
            startActivity(chooser);
        }
    }


    public void compartirOtrasApps(){
            try {

                Picasso.with(this)
                        .load(urlFoto)
                        .into(new Target() {
                            @Override
                            public void onBitmapLoaded(Bitmap bitmap, Picasso.LoadedFrom from) {
                                // loaded bitmap is here (bitmap)
                                if (bitmap != null) {
                                    Uri img = getImageUri(context, bitmap);
                                    adjuntarImagen(img);
                                }
                            }

                            @Override
                            public void onBitmapFailed(Drawable errorDrawable) {

                                Intent intent = new Intent();
                                intent.setAction(Intent.ACTION_SEND);

                                // insertamos los datos en el intent y especificamos el tipo
                                intent.putExtra(Intent.EXTRA_TEXT,  R.string.texto_share_tira_ramo);
                                intent.setType("text/plain");

                                // Generamos un selector con las aplicaciones disponibles para hacer el envío de información
                                Intent chooser = Intent.createChooser(intent, "Compartir mediante otras aplicaciones");
                                if (intent.resolveActivity(getPackageManager()) != null) {
                                    startActivity(chooser);
                                }

                            }

                            @Override
                            public void onPrepareLoad(Drawable placeHolderDrawable) {

                            }
                        });
            } catch (Exception e) {
                Log.d("Detalle", e.toString());
            }
    }


    private Uri getImageUri(Context inContext, Bitmap inImage) {
        ByteArrayOutputStream bytes = new ByteArrayOutputStream();
        inImage.compress(Bitmap.CompressFormat.PNG, 100, bytes);
        String path = MediaStore.Images.Media.insertImage(inContext.getContentResolver(), inImage, "image", null);
        return Uri.parse(path);
    }



    @Override
    public void onRequestPermissionsResult(int requestCode, String permissions[], int[] grantResults) {
        switch (requestCode) {

            case PERMISO_REQUEST_WRITE_EXTERNAL_STORAGE:
                // Si el permiso ha sido concedido, ejecutamos el método compartirOtrasApps
                if (grantResults.length > 0
                        && grantResults[0] == PackageManager.PERMISSION_GRANTED) {
                    compartirOtrasApps();
                    permisos = true;

                } else { // Si no, informamos al usuario de la situación con un alert
                    Toast.makeText(this, getString(R.string.alerra_permiso_almacenamiento), Toast.LENGTH_SHORT).show();
                    permisos = false;
                }
                break;

        }
    }



    private void buscarProductoById() {
        String tag_string_req = "req_product";


        StringRequest strReq = new StringRequest(Request.Method.POST,
                AppConfig.URL_PRODUCTS, new Response.Listener<String>() {

            @Override
            public void onResponse(String response) {
                Log.d(TAG, "Product Response: " + response.toString());

                try {
                    JSONObject jObj = new JSONObject(response);

                    // comprobar si hay error
                    cargarObjeto(jObj);
                } catch (JSONException e) {
                    // JSON error
                    e.printStackTrace();
                    Toast.makeText(getApplicationContext(), "Json error: " + e.getMessage(), Toast.LENGTH_LONG).show();
                }

            }
        }, new Response.ErrorListener() {

            @Override
            public void onErrorResponse(VolleyError error) {
                Log.e(TAG, "Error al obtener producto by id: " + error.getMessage());
                Toast.makeText(getApplicationContext(),
                        error.getMessage(), Toast.LENGTH_LONG).show();
            }
        }) {

            @Override
            protected Map<String, String> getParams() {
                // Posting parameters to login url
                Map<String, String> params = new HashMap<String, String>();
                params.put("id", id);

                return params;
            }

        };

        // Adding request to request queue
        AppController.getInstance().addToRequestQueue(strReq, tag_string_req);
    }



    private  void cargarObjeto(JSONObject jObject) {

        try{

            JSONObject product = jObject.getJSONObject("product");

            String name = product.getString("name");
            if (name == "null" || name == null)
                name = "";

            String id = "" + product.getInt("id");

            String description =product.getString("description");
            if (description == "null" || description == null)
                description = "";

            String material = product.getString("material");
            if (material == "null" || material == null)
                material = "";

            String photo = product.getString("photo");
            if (photo == "null" || photo == null)
                photo = "";

            String user = product.getString("user");
            if (user == "null" || user == null )
                user = "";

            String price = product.getString("price");
            if (price == "null" || price == null)
                price = "";

            String ref = product.getString("reference");
            if (ref == "null" || ref == null)
                ref = "";

            String min = "" + product.getString("min_size");
            if (min == "null" || min == "")
                min = "0";

            String max = "" + product.getString("max_size");
            if (max == "null" || max == "")
                max = "0";

            String quantity = product.getString("quantity");
            if (name == "null" || quantity == null)
                name = "1";

            String categoria = product.getString("category");
            if (categoria == "null" || categoria == null)
                categoria = "1";

            String url = product.getString("url");
            if (url == "null")
                url = DEFAULT_URL;

            //listaProductos.add(new Producto(id, name, price, description, categoria, photo, material, min, max, quantity, ref, url));

            // Actualizar vistas
            nombre = name;
            descripcion = ref + "\n\n" + description + "\n\n" + price + "€";
            urlFoto = photo;
            urlCompra = url;

            mItem = new Producto(id, name, price, description, categoria, photo, material, min, max, quantity, ref, url);
            cargarVistas();

        } catch (Exception e) {
            e.printStackTrace();
        }
    }
}
