package currentweek.android.uoc.edu.aliapp;

import android.content.Context;
import android.content.Intent;
import android.graphics.Color;
import android.support.annotation.NonNull;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.support.v7.widget.DefaultItemAnimator;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.util.Log;
import android.view.LayoutInflater;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.ViewGroup;
import android.widget.Button;
import android.widget.ImageButton;
import android.widget.ImageView;
import android.widget.TextView;
import android.widget.Toast;

import com.squareup.picasso.Picasso;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

import model.Producto;
import model.SQLiteHandler;

import static currentweek.android.uoc.edu.aliapp.MainActivity.session;

public class FavoritosActivity extends AppCompatActivity {

    private String tipoLista;

    private RecyclerView recyclerView;
    private SimpleItemRecyclerViewAdapterFavoritos adapter = null;

    private List<Producto> listaFavoritos;

    private Context context;

    private SQLiteHandler db;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_favoritos);

        listaFavoritos = new ArrayList<Producto>();

        recyclerView = (RecyclerView) findViewById(R.id.listaFavoritos);
        context = this.getApplicationContext();

        cargarFavoritos();

        // habilitar botón atrás
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);

    }


    public static Intent makeIntent(Context context) {
        return new Intent(context, FavoritosActivity.class);
    }

    private void cargarFavoritos() {
        // Obtener los valores almacenados en base de datos
        db = new SQLiteHandler(getApplicationContext());
        List<HashMap<String, String>> productosBBDD = db.getFavoritos();

        for (HashMap<String, String> p:productosBBDD) {
            String name = p.get("name");
            String id = p.get("id");
            String des = p.get("description");
            String cat = p.get("category");
            String photo = p.get("photo");
            String price = p.get("price");

            listaFavoritos.add(new Producto(id, name, price, des, cat, photo,"", "0", "0", "1", "", ""));

        }

        adapter = new SimpleItemRecyclerViewAdapterFavoritos(listaFavoritos);
        RecyclerView.LayoutManager mLayoutManager = new LinearLayoutManager(getApplicationContext());
        recyclerView.setLayoutManager(mLayoutManager);
        recyclerView.setItemAnimator(new DefaultItemAnimator());
        recyclerView.setAdapter(adapter);
    }


    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_superior, menu);
        return true;
    }


    @Override
    public boolean onPrepareOptionsMenu(Menu menu) {

        MenuItem btnSesion = menu.findItem(R.id.action_settings);
        btnSesion.setVisible(false);

        MenuItem btnFav = menu.findItem(R.id.action_settings_favoritos);
        btnFav.setVisible(false);

        return true;
    }


    @Override
    public boolean onOptionsItemSelected(MenuItem item) {

        switch (item.getItemId()) {
            case android.R.id.home: //hago un case por si en un futuro agrego mas opciones
                Log.i("ActionBar", "Atrás!");
                finish();
                return true;

            case R.id.action_settings_home:
                Intent goHome = MainActivity.makeIntent(this);
                startActivity(goHome);
                return true;

            default:
                return super.onOptionsItemSelected(item);
        }

    }

    public class SimpleItemRecyclerViewAdapterFavoritos extends RecyclerView.Adapter<SimpleItemRecyclerViewAdapterFavoritos.ViewHolder> {

        private List<Producto> mValues;


        public class ViewHolder extends RecyclerView.ViewHolder {
            // Views of each item of the list
            public View mView;
            public ImageView mFoto;
            public TextView mTitulo;
            public TextView mPrecio;
            public Button btnEliminar;



            /*
             * Constructor that defines the views
             * */
            public ViewHolder(View view) {
                super(view);

                mView = view;
                mFoto = view.findViewById(R.id.fotoFavorito);
                mTitulo = view.findViewById(R.id.lblTituloCatalogo);
                mPrecio = view.findViewById(R.id.lblPrecioFavorito);
                btnEliminar = view.findViewById(R.id.btnEliminarFavorito);

            }

        }


        /*
         * Constructor that loads the list content
         * */
        public SimpleItemRecyclerViewAdapterFavoritos(List<Producto> myDataset) {
            mValues = myDataset;
        }

        /*
         * We establish the model of each item of the list
         * */
        @NonNull
        @Override
        public SimpleItemRecyclerViewAdapterFavoritos.ViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {

            View v = LayoutInflater.from(parent.getContext()).inflate(R.layout.item_favorito, parent, false);
            SimpleItemRecyclerViewAdapterFavoritos.ViewHolder vh = new SimpleItemRecyclerViewAdapterFavoritos.ViewHolder(v);

            return vh;

        }


        /*
         * In each item of the list, we upload the information of a follower
         * */
        @Override
        public void onBindViewHolder(@NonNull SimpleItemRecyclerViewAdapterFavoritos.ViewHolder holder, final int position) {

            // Set different colors for even and odd cells
            if (position % 2 == 0)
                holder.mView.setBackgroundColor(Color.parseColor("#ffffff"));
            else
                holder.mView.setBackgroundColor(Color.parseColor("#ece6b6"));

            // Set follower info
            Producto item = mValues.get(position);

            holder.mTitulo.setText(item.getNombre());
            holder.mPrecio.setText(item.getPrecio() + "€");

            String urlFoto = item.getFoto();

            if (urlFoto != null && urlFoto != "")
                Picasso.with(context).load(urlFoto).into(holder.mFoto);

            // Colocamos el listener
            holder.mView.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {

                    Intent i = new Intent(context, DetalleProductoActivity.class);
                    i.putExtra(DetalleProductoActivity.CURRENT_ID, mValues.get(position).getId());
                    startActivity(i);

                }
            });

            holder.btnEliminar.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {

                    // Eliminar favorito de la base de datos
                    db.deleteFav(mValues.get(position).getId());

                    Log.d("borrando en SQLite", "borrando");

                    Toast.makeText(context, "El elemento ha sido borrado de la lista", Toast.LENGTH_SHORT).show();

                    // Actualizar lista lanzando una nueva actividad
                    startActivity(FavoritosActivity.makeIntent(context));
                    finish();
                }
            });

        }

        @Override
        public int getItemCount() {
            return mValues.size();
        }

    }
}
