package currentweek.android.uoc.edu.aliapp;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Toast;


import com.android.volley.Request.Method;
import com.android.volley.Response;
import com.android.volley.VolleyError;
import com.android.volley.toolbox.StringRequest;

import org.json.JSONException;
import org.json.JSONObject;

import java.util.HashMap;
import java.util.Map;

import model.AppConfig;
import model.AppController;
import model.SendMail;

import static currentweek.android.uoc.edu.aliapp.MainActivity.session;

public class LoginActivity extends AppCompatActivity {

    private EditText inputUsername;
    private EditText inputPassword;

    private Button btnAcceder;
    private Button btnIrSolicitar;

    private Context context;


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_login);

        inputUsername = (EditText) findViewById(R.id.username);
        inputPassword = (EditText) findViewById(R.id.password);

        context = this.getApplicationContext();

        // Habilitar botón atrás barra
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);
        // Colocar título a la ventana
        getSupportActionBar().setTitle("Acceso clientes");


        // Si ya se está logueado en la aplicación, directamente pasar a AreaNoviosActivity
        if (session.isLoggedIn()) {
            Log.d("login", "shared prefered - está logueado");
            Intent intent = AreaNoviosActivity.makeIntent(this);
            startActivity(intent);
            finish();
        }
        Log.d("login", "shared prefered - no está logueado");


        btnAcceder = findViewById(R.id.btnAccederJuego);
        btnAcceder.setOnClickListener(new View.OnClickListener() {

            public void onClick(View view) {
                acceder();
            }
        });


        btnIrSolicitar = findViewById(R.id.btnSolicitar);
        btnIrSolicitar.setOnClickListener(new View.OnClickListener() {

            public void onClick(View view) {
               irSolicitarUsuario();
            }
        });
    }


    public static Intent makeIntent(Context context) {
        return new Intent(context, LoginActivity.class);
    }




    private boolean comprobarLogueado() {
        // shared preferences
        return true;
    }


    public void acceder() {
        String email = inputUsername.getText().toString().trim();
        String password = inputPassword.getText().toString().trim();

        Log.d("login", "datos recogidos - " + email + " " + password);

        // Comprobar que los campos no estén vacíos
        if (!email.isEmpty() && !password.isEmpty())
            checkLogin(email, password);
        else
            Toast.makeText(getApplicationContext(), R.string.alerta_login_credenciales, Toast.LENGTH_LONG).show();

    }



    private void checkLogin(final String email, final String password) {
        // Tag used to cancel the request
        String tag_string_req = "req_login";


        StringRequest strReq = new StringRequest(Method.POST,
                AppConfig.URL_LOGIN, new Response.Listener<String>() {

            @Override
            public void onResponse(String response) {
                Log.d("login", "Login Response: " + response.toString());

                try {
                    JSONObject jObj = new JSONObject(response);
                    boolean error = jObj.getBoolean("error");

                    // Check for error node in json
                    if (!error) {
                        // Crear sesion login
                        session.setLogin(true);

                        // Almacenar datos en Shared Prefered
                        session.setUserData(jObj);

                        // Lanzar área de novios
                        Intent intent = AreaNoviosActivity.makeIntent(context);
                        startActivity(intent);
                        finish();
                    } else {
                        // Error in login. Get the error message
                        String errorMsg = jObj.getString("error_msg");
                        Toast.makeText(getApplicationContext(),
                                errorMsg, Toast.LENGTH_LONG).show();
                    }
                } catch (JSONException e) {
                    // JSON error
                    e.printStackTrace();
                    Toast.makeText(getApplicationContext(), "Json error: " + e.getMessage(), Toast.LENGTH_LONG).show();
                }

            }
        }, new Response.ErrorListener() {

            @Override
            public void onErrorResponse(VolleyError error) {
                Log.e("login", "Login Error: " + error.getMessage());
                Toast.makeText(getApplicationContext(),
                        error.getMessage(), Toast.LENGTH_LONG).show();
            }
        }) {

            @Override
            protected Map<String, String> getParams() {
                // Posting parameters to login url
                Map<String, String> params = new HashMap<String, String>();
                params.put("email", email);
                params.put("password", password);

                return params;
            }

        };

        // Adding request to request queue
        AppController.getInstance().addToRequestQueue(strReq, tag_string_req);
    }


    public void irSolicitarUsuario() {
        Intent intent = SolicitarUsuario.makeIntent(this);
        startActivity(intent);
    }
}
