package currentweek.android.uoc.edu.aliapp;

import android.content.Context;
import android.content.Intent;
import android.os.Handler;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.view.animation.Animation;
import android.view.animation.AnimationUtils;
import android.widget.ImageSwitcher;
import android.widget.ImageView;
import android.widget.Toast;
import android.widget.ViewSwitcher;

import com.squareup.picasso.Picasso;

import java.io.File;
import java.util.Timer;
import java.util.TimerTask;

import model.ImageSwitcherPicasso;
import model.SessionManager;

/**
 * Esta es la clase principal de la aplicación, el activity es lanzado nada más arrancar
 * la app. Cuenta con cuatro botones que conducen al usuario a los puntos principales de
 * la aplicación (Área de novios, catálogo de novios, catálogo de padrinos y madrinas y
 * relojes). Por su parte, cuenta con un ImageSwitcher en la parte inferior de la pantalla
 * que da vida a un slider con las publicidades de la empresa.
 */
public class MainActivity extends AppCompatActivity {

    public static SessionManager session;       // Datos en el dispositivo referentes al usuario

    public static boolean fotoMail = false;     // Variable booleana que especifica si el mail a componer lleva o no foto adjunta

    // Tipos de catálogos extra a los de los apartados de novios (alianzas y anillos de pedida)
    private final String TIPO_CATALOGO = "TIPO_CATALOGO";
    private final String PAD = "PADRINOS";
    private final String NVS = "NOVIOS";
    private final String REL = "RELOJES";

    private Context context;

    private ImageSwitcher imageSwitcher;        // Para el banner de publicidad

    // Array con los banners
    private String[] galleryString = {"https://joyeriasadeley.com/modules/azhomeslider/images/2a1c15835f24c654452e7be7aa0e2d896e0f0017_ce7cac6bf2cdbfe574e564ce5e4bcb3159fbf830_montblanc mas pequeña.jpg",
            "https://joyeriasadeley.com/modules/azhomeslider/images/83ffa44701e1310f9bf0d139f1efd590924cbf59_05d1ec483a916c976c74cc25326557ca07658782_26230627_1181783265257629_971726667350361188_n.jpg",
            "https://joyeriasadeley.com/modules/azhomeslider/images/8e3620e74316fa7b1cf0b407a9f2d36705537ade_19225784_674071309461539_7682718116423751510_n.jpg",
            "https://joyeriasadeley.com/modules/azhomeslider/images/56f35392bbef99c709f717682e8e83f96e56229a_18300892_657207164481287_8636265599011022996_n.jpg"
                                    };
    private int position;
    private static final Integer DURATION = 2500;
    private Timer timer = null;

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);
        imageSwitcher = (ImageSwitcher) findViewById(R.id.imageSwitcher);
        imageSwitcher.setFactory(new ViewSwitcher.ViewFactory() {

            public View makeView() {
                return new ImageView(MainActivity.this);
            }
        });


        context = getApplicationContext();

        // Session manager
        session = new SessionManager(getApplicationContext());


        // Colocar animations
        Animation fadeIn = AnimationUtils.loadAnimation(this, R.anim.fade_in);
        Animation fadeOut = AnimationUtils.loadAnimation(this, R.anim.fade_out);
        imageSwitcher.setInAnimation(fadeIn);
        imageSwitcher.setOutAnimation(fadeOut);

        startSlider();

    }



    public static Intent makeIntent(Context context) {
        return new Intent(context, MainActivity.class);
    }



    // Métodos para abrir los diferentes catálogos (activities)
    public void irCatalogoPadrinos(View view){
        Intent intent = CatalogoActivity.makeIntent(this);
        intent.putExtra(TIPO_CATALOGO, PAD);
        startActivity(intent);
    }


    public void irCatalogoNovios(View view){
        Intent intent = CatalogoActivity.makeIntent(this);
        intent.putExtra(TIPO_CATALOGO, NVS);
        startActivity(intent);
    }

    public void irCatalogoRelojes(View view){
        Intent intent = CatalogoActivity.makeIntent(this);
        intent.putExtra(TIPO_CATALOGO, REL);
        startActivity(intent);
    }

    public void irAreaNovios(View view){
        Intent intent = LoginActivity.makeIntent(this);
        startActivity(intent);
    }



    // Start slider
    public void start(View button) {
        if (timer != null) {
            timer.cancel();
        }
        position = 0;
        startSlider();
    }

    // Stop slider
    public void stop(View button) {
        if (timer != null) {
            timer.cancel();
            timer = null;
        }
    }

    public void startSlider() {
        timer = new Timer();
        timer.scheduleAtFixedRate(new TimerTask() {

            public void run() {

                runOnUiThread(new Runnable() {
                    public void run() {

                        // Utilizamos la librería Picasso para cargar los banners
                        ImageSwitcherPicasso mImageSwitcherPicasso = new ImageSwitcherPicasso(context, imageSwitcher);
                        Picasso.with(context)
                                .load(galleryString[position])
                                .into(mImageSwitcherPicasso);

                        position++;
                        if (position == galleryString.length) {
                            position = 0;
                        }
                    }
                });
            }

        }, 0, DURATION);
    }


    // Stops the slider when the Activity is going into the background
    @Override
    protected void onPause() {
        super.onPause();

        if (timer != null) {
            timer.cancel();
            timer = null;
        }
    }

    @Override
    protected void onResume() {
        super.onResume();

        if (timer != null) {
            timer.cancel();
        }
        position = 0;
        startSlider();
    }
}
