package currentweek.android.uoc.edu.aliapp;

import android.content.Context;
import android.content.Intent;
import android.graphics.Color;
import android.support.annotation.NonNull;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.support.v7.widget.DefaultItemAnimator;
import android.support.v7.widget.LinearLayoutManager;
import android.support.v7.widget.RecyclerView;
import android.support.v7.widget.StaggeredGridLayoutManager;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageView;
import android.widget.TextView;

import com.squareup.picasso.Picasso;

import java.util.List;

import model.Producto;

public class ResultadoTestActivity extends AppCompatActivity {

    private RecyclerView recyclerView;

    private ResultRecyclerViewAdapter adapter = null;
    private Context context;
    private List<Producto> listaProductosResultado;

    private TextView lblResultado;
    public final static String COD_RESULTADO = "COD_RESULTADO";


    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_resultado_test);

        // Colocar título a la ventana
        getSupportActionBar().setTitle("Resultado");

        recyclerView = (RecyclerView) findViewById(R.id.recyclerViewResultado);
        lblResultado = findViewById(R.id.lblResultado);

        context = this.getApplicationContext();

        // Obtener frase resultado
        lblResultado.setText(JuegaEnParejaActivity.nuevoTest.getResultadoDefinitivo());

        // Obtener lista de productos asociado al resultado
        listaProductosResultado = JuegaEnParejaActivity.nuevoTest.getListaProductosDefinitivos();

        // Lista de productos de la app de la que obtendrá la info la activity detalle
        ArticuloActivity.setListaProductos(listaProductosResultado);

        adapter = new ResultRecyclerViewAdapter(listaProductosResultado);

        recyclerView.setLayoutManager(new StaggeredGridLayoutManager(3, LinearLayoutManager.VERTICAL));
        recyclerView.setItemAnimator(new DefaultItemAnimator());
        recyclerView.setAdapter(adapter);


    }


    public static Intent makeIntent(Context context) {
        return new Intent(context, ResultadoTestActivity.class);
    }


    public void volverAJugar(View view) {
        Intent intent = JuegaEnParejaInfoActivity.makeIntent(this);
        startActivity(intent);
        finish();
    }


    public class ResultRecyclerViewAdapter extends RecyclerView.Adapter<ResultRecyclerViewAdapter.ViewHolder> {

        private List<Producto> mValues;


        public class ViewHolder extends RecyclerView.ViewHolder {
            // Views of each item of the list
            public View mView;
            public ImageView mFoto;


            /*
             * Constructor that defines the views
             * */
            public ViewHolder(View view) {
                super(view);

                mView = view;
                mFoto = (ImageView) view.findViewById(R.id.fotoProducto);

            }

        }


        /*
         * Constructor that loads the list content
         * */
        public ResultRecyclerViewAdapter(List<Producto> myDataset) {
            mValues = myDataset;
        }

        /*
         * We establish the model of each item of the list
         * */
        @NonNull
        @Override
        public ResultRecyclerViewAdapter.ViewHolder onCreateViewHolder(@NonNull ViewGroup parent, int viewType) {

            View v = LayoutInflater.from(parent.getContext()).inflate(R.layout.item_producto, parent, false);
            ResultRecyclerViewAdapter.ViewHolder vh = new ResultRecyclerViewAdapter.ViewHolder(v);

            return vh;

        }


        /*
         * In each item of the list, we upload the information of a follower
         * */
        @Override
        public void onBindViewHolder(@NonNull ResultRecyclerViewAdapter.ViewHolder holder, final int position) {

            // Set different colors for even and odd cells
            if (position % 2 == 0)
                holder.mView.setBackgroundColor(Color.parseColor("#595959"));
            else
                holder.mView.setBackgroundColor(Color.parseColor("#000000"));



            // Set follower info
            Producto articulo = mValues.get(position);

            String urlFoto = articulo.getFoto();

            if (urlFoto != null && urlFoto != "")
                Picasso.with(context).load(urlFoto).into(holder.mFoto);


            // Colocamos el listener
            holder.mView.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {

                    Intent i = new Intent(context, DetalleProductoActivity.class);
                    i.putExtra(DetalleProductoActivity.CURRENT_POSITION, position + 1);
                    startActivity(i);

                }
            });

        }

        @Override
        public int getItemCount() {
            return mValues.size();
        }

    }
}
