package currentweek.android.uoc.edu.aliapp;

import android.content.Context;
import android.content.Intent;
import android.content.pm.PackageManager;
import android.graphics.Bitmap;
import android.graphics.drawable.Drawable;
import android.net.Uri;
import android.os.Build;
import android.provider.MediaStore;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.Toast;

import com.squareup.picasso.Picasso;
import com.squareup.picasso.Target;

import java.io.ByteArrayOutputStream;

import model.AppConfig;
import model.SendMail;

import static currentweek.android.uoc.edu.aliapp.MainActivity.session;



public class TiraTuRamoActivity extends AppCompatActivity {

    private boolean permisos = false;

    private Context context;

    private EditText direccion;
    private EditText municipio;
    private EditText edificio;
    private EditText numero;
    private EditText puerta;
    private EditText cp;

    private Button btnTiraRamo;

    private static final int SHARE_OTHER = 400;

    // Identificador de permisos
    private static final int PERMISO_REQUEST_WRITE_EXTERNAL_STORAGE = 101;
    private static final int COMPARTIR_APP = 102;



    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_tira_tu_ramo);

        // Habilitar botón atrás barra
        getSupportActionBar().setDisplayHomeAsUpEnabled(true);

        // Colocar título a la ventana
        getSupportActionBar().setTitle("Tira tu ramo");

        // Obtener todos los campos a rellenar
        direccion = findViewById(R.id.editDireccion);
        municipio = findViewById(R.id.editMunicipio);
        cp = findViewById(R.id.editCP);
        edificio = findViewById(R.id.editEdificio);
        numero = findViewById(R.id.editNumero);
        puerta = findViewById(R.id.editPuerta);

        // Rellenar los campos por defecto con los datos del usuario logueado
        direccion.setText(session.getUserDireccion());
        municipio.setText(session.getUserMunicipio());
        cp.setText(session.getUserCP());
        edificio.setText(session.getUserEd());
        numero.setText(session.getUserNumero());
        puerta.setText(session.getUserPuerta());

        context = this.getApplicationContext();

        btnTiraRamo = findViewById(R.id.btnTiraRamo);
        btnTiraRamo.setOnClickListener(new View.OnClickListener() {

            public void onClick(View view) {
                if(permisos)
                    tirarRamo();
                else
                    preguntarPermisos();
            }
        });
    }


    public static Intent makeIntent(Context context) {
        return new Intent(context, TiraTuRamoActivity.class);
    }



    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_superior, menu);
        return true;
    }


    @Override
    public boolean onOptionsItemSelected(MenuItem item) {

        switch (item.getItemId()) {
            case android.R.id.home: //hago un case por si en un futuro agrego mas opciones
                Log.i("ActionBar", "Atrás!");
                finish();
                return true;

            case R.id.action_settings:
                session.setLogin(false);
                Toast.makeText(this, R.string.cerrar_sesion, Toast.LENGTH_SHORT).show();
                Log.d("sesion", "Cerrando sesión...");

                Intent intent = MainActivity.makeIntent(this);
                startActivity(intent);
                finish();
                return true;

            case R.id.action_settings_favoritos:
                Log.d("favoritos", "Ver favoritos");

                Intent i = FavoritosActivity.makeIntent(this);
                startActivity(i);
                return true;

            case R.id.action_settings_home:
                Intent goHome = MainActivity.makeIntent(this);
                startActivity(goHome);
                return true;

            default:
                return super.onOptionsItemSelected(item);
        }

    }



    private void preguntarPermisos() {
        // Versiones superiores de android con solicitud de permisos en tiempo de ejecución
        if (Build.VERSION.SDK_INT >= 23) {
            // Comprobar el estado del permiso que necesitamos
            int permisoEscritura = checkSelfPermission(android.Manifest.permission.WRITE_EXTERNAL_STORAGE);

            // Si no se tiene el permiso, según la acción se solicitará el permiso que neceistamos
            if (permisoEscritura != PackageManager.PERMISSION_GRANTED) {
                requestPermissions(new String[]{android.Manifest.permission.WRITE_EXTERNAL_STORAGE},
                        PERMISO_REQUEST_WRITE_EXTERNAL_STORAGE);
            // Si se tiene el permiso
            } else if (permisoEscritura == PackageManager.PERMISSION_GRANTED){
                tirarRamo();
            }
            permisos = true;
        }
        else {
            permisos = true;
            tirarRamo();
        }
    }



    private Uri getImageUri(Context inContext, Bitmap inImage) {
        ByteArrayOutputStream bytes = new ByteArrayOutputStream();
        inImage.compress(Bitmap.CompressFormat.PNG, 100, bytes);
        String path = MediaStore.Images.Media.insertImage(inContext.getContentResolver(), inImage, "image", null);
        return Uri.parse(path);
    }


    private void adjuntarImagen(Uri img) {
        Intent intent = new Intent();
        intent.setAction(Intent.ACTION_SEND);
        intent.putExtra(Intent.EXTRA_STREAM, img);
        intent.putExtra(Intent.EXTRA_TEXT, getString(R.string.texto_share_tira_ramo));

        intent.setType("image/*");

        // Generamos un selector con las aplicaciones disponibles para hacer el envío de información
        Intent chooser = Intent.createChooser(intent, "Compartir otras aplicaciones");
        if (intent.resolveActivity(getPackageManager()) != null) {
            startActivityForResult(chooser, COMPARTIR_APP);
        }
    }


    private void tirarRamo() {
        try {
            // Enviar un mail a los joyeros con la información del usuario

            Picasso.with(this)
                .load(AppConfig.LOGO_JOYERIA)
                .into(new Target() {
                    @Override
                    public void onBitmapLoaded(Bitmap bitmap, Picasso.LoadedFrom from) {
                        // loaded bitmap is here (bitmap)
                        if (bitmap != null) {
                            // Convertimos el bitmap en uri par enviarlo
                            Uri img = getImageUri(context, bitmap);
                            adjuntarImagen(img);
                        }
                    }

                    @Override
                    public void onBitmapFailed(Drawable errorDrawable) {

                        Intent intent = new Intent();
                        intent.setAction(Intent.ACTION_SEND);

                        // insertamos los datos en el intent y especificamos el tipo
                        intent.putExtra(Intent.EXTRA_TEXT,  getString(R.string.texto_share_tira_ramo));
                        intent.setType("text/plain");

                        // Generamos un selector con las aplicaciones disponibles para hacer el envío de información
                        Intent chooser = Intent.createChooser(intent, "Compartir mediante otras aplicaciones");
                        if (intent.resolveActivity(getPackageManager()) != null) {
                            startActivityForResult(chooser, COMPARTIR_APP);
                        }

                    }

                    @Override
                    public void onPrepareLoad(Drawable placeHolderDrawable) {

                    }
                });
        } catch (Exception e) {
            Log.d("tira tu ramo", e.toString());
        }
    }



    @Override
    protected void onActivityResult(int requestCode, int resultCode, Intent data) {
        // Check which request we're responding to
        if (requestCode == COMPARTIR_APP) {
            // Make sure the request was successful
            if (resultCode == RESULT_OK) {
                // La aplicación se ha compartido con éxito, por lo que enviamos los datos a la empresa
                // para que pueda enviar un obsequio al usuario

                MainActivity.fotoMail = false;

                // Crear correo con los datos recogidos
                String contenido = "El usuario " + session.getUser() + " (" + session.getMail() + ") acaba de compartir la app. <br>" +
                                   "La dirección a la que se deberá enviar el obsequio es la siguiente: <br>" +
                                   "Direccion: " + direccion.getText() + ", " + numero.getText() + ". <br>" +
                                   "Edificio: " + edificio.getText() + ". Puerta: " + puerta.getText() + "<br>" +
                                   "Municipio: " + municipio.getText() + " (" + cp.getText() + ")<br>";

                // Enviar correo con los datos
                new SendMail(AppConfig.USER_MAIL, AppConfig.PASS_MAIL).execute(
                        new SendMail.Mail(AppConfig.USER_MAIL, AppConfig.USER_MAIL, getString(R.string.asunto_correo), contenido)
                );

                Toast.makeText(this, R.string.alert_share_ok, Toast.LENGTH_LONG).show();
            }
            else {
                Toast.makeText(this, R.string.alerta_no_obsequio, Toast.LENGTH_LONG).show();
            }
        }
    }



    @Override
    public void onRequestPermissionsResult(int requestCode, String permissions[], int[] grantResults) {
        switch (requestCode) {

            case PERMISO_REQUEST_WRITE_EXTERNAL_STORAGE:
                // Si el permiso ha sido concedido, ejecutamos el método compartirOtrasApps
                if (grantResults.length > 0
                        && grantResults[0] == PackageManager.PERMISSION_GRANTED) {
                    tirarRamo();
                    permisos = true;

                } else { // Si no, informamos al usuario de la situación con un alert
                    Toast.makeText(this, getString(R.string.alerra_permiso_almacenamiento), Toast.LENGTH_SHORT).show();
                    permisos = false;
                }
                break;

        }
    }


}
