package model;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;
import android.util.Log;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;

public class SQLiteHandler extends SQLiteOpenHelper {

    private static final String TAG = "SQLiteHandler";

    // All Static variables
    // Database Version
    private static final int DATABASE_VERSION = 1;

    // Database Name
    private static final String DATABASE_NAME = "android_api";

    // Login table name
    private static final String TABLA_PRODUCTO = "producto";

    // Login Table Columns names
    private static final String KEY_ID = "id_product";
    private static final String KEY_NAME = "name";
    private static final String KEY_DESCRIPTION = "description";
    private static final String KEY_CATEGORY = "category";
    private static final String KEY_PHOTO = "photo";
    private static final String KEY_PRICE = "price";





    public SQLiteHandler(Context context) {
        super(context, DATABASE_NAME, null, DATABASE_VERSION);
    }

    // Creating Tables
    @Override
    public void onCreate(SQLiteDatabase db) {
        String CREATE_LOGIN_TABLE = "CREATE TABLE " + TABLA_PRODUCTO + "("
                + KEY_ID + " INTEGER PRIMARY KEY," + KEY_NAME + " TEXT,"
                + KEY_DESCRIPTION + " TEXT," + KEY_CATEGORY + " TEXT,"
                + KEY_PRICE + " TEXT," + KEY_PHOTO + " TEXT" + ")";
        db.execSQL(CREATE_LOGIN_TABLE);

        Log.d(TAG, "Database tables created");
    }



    // Upgrading database
    @Override
    public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
        // Drop older table if existed
        db.execSQL("DROP TABLE IF EXISTS " + TABLA_PRODUCTO);

        // Create tables again
        onCreate(db);
    }



    /**
     * Método para almacenar producto
     * */
    public void insertarProducto(String name, String description, int id, String category, String photo, String price) {
        SQLiteDatabase db = this.getWritableDatabase();

        ContentValues values = new ContentValues();
        values.put(KEY_ID, id);
        values.put(KEY_NAME, name);
        values.put(KEY_DESCRIPTION, description);
        values.put(KEY_CATEGORY, category);
        values.put(KEY_PRICE, price);
        values.put(KEY_PHOTO, photo);


        // Inserting Row
        long row_id = db.insert(TABLA_PRODUCTO, null, values);
        db.close(); // Closing database connection

        Log.d(TAG, "Nuevo producto insertado: " + row_id);
    }



    /**
     * Obtener producto de la base de datos
     * */
    public List<HashMap<String, String>> getFavoritos() {
        List<HashMap<String, String>> productosFavoritos = new ArrayList<HashMap<String, String>>();


        String selectQuery = "SELECT  * FROM " + TABLA_PRODUCTO;

        SQLiteDatabase db = this.getReadableDatabase();
        Cursor cursor = db.rawQuery(selectQuery, null);
        // Move to first row
        cursor.moveToFirst();

        for (int i = 0; i < cursor.getCount(); i++) {
            HashMap<String, String> user = new HashMap<String, String>();
            user.put("id", "" + cursor.getInt(0));
            user.put("name", cursor.getString(1));
            user.put("description", cursor.getString(2));
            user.put("category", cursor.getString(3));
            user.put("price", cursor.getString(4));
            user.put("photo", cursor.getString(5));

            productosFavoritos.add(user);
            //move to the next row
            cursor.moveToNext();
        }

        cursor.close();
        db.close();
        // return user
        Log.d(TAG, "Obteniendo favoritos de la base de datos: ");

        return productosFavoritos;
    }


    public boolean existProduct(String id) {
        String selectQuery = "SELECT  * FROM " + TABLA_PRODUCTO + " WHERE " + KEY_ID + "=" + id ;

        SQLiteDatabase db = this.getReadableDatabase();
        Cursor cursor = db.rawQuery(selectQuery, null);
        // Move to first row
        cursor.moveToFirst();


        if (cursor.getCount() > 0) {
            cursor.close();
            db.close();
            return true;
        }
        else {
            cursor.close();
            db.close();
            return false;
        }

    }



    /**
     * Re crate database Delete all tables and create them again
     * */
    public void deleteProducts() {
        SQLiteDatabase db = this.getWritableDatabase();
        // Delete All Rows
        db.delete(TABLA_PRODUCTO, null, null);
        db.close();

        Log.d(TAG, "Todos los productos borrados");
    }


    public boolean deleteFav (String id) {

        String selectQuery = "DELETE FROM " + TABLA_PRODUCTO + " WHERE " + KEY_ID + "=" + id;
        SQLiteDatabase db = this.getReadableDatabase();
        Cursor cursor = db.rawQuery(selectQuery, null);
        // Move to first row
        cursor.moveToFirst();


        if (cursor.getCount() > 0) {
            cursor.close();
            db.close();
            return true;
        }
        else {
            cursor.close();
            db.close();
            return false;
        }
    }

}
